/**
 * Genau 1 - Manual Plotter
 * An example of interactive use of the Control class.
 *
 * Note:
 * The position coordinates are expressed in motor steps: 
 * 80 steps = 1mm
 *
 * Keys:
 * SPACEBAR    Raise/lower the pen
 * ENTER       Move the Axidraw to the location of the mouse
 * LEFT MOUSE  Add a waypoint
 * p           Begin drawing bewteen all waypoints, then clear them
 * SHIFT + P   Clear all waypoints
 * t           Axidraw will begin to follow the mouse [!Warning!] this function doesn't work particularly well.
 *             
 */

Control c;
int ratio;
int tempX;
int tempY;

void setup() {
  size(420, 297);
  ratio = 80;
  
  c = new Control(this);  // Initialize the control class
  Serial p = c.open();    // Open the serial port
  if (p == null) {  
    println("Axidraw not found.");
    exit();               // No AxiDraw - no joy!
    return;
  } 
  c.readPos();            // Read out the steps from the EBB, set internal pos[] accordingly;
                          // this makes sure that the position is updated when re-launching the program
                          // so a "reset" (via zero()) is not needed
  c.up(true);             // Force the pen to be "up" 
  
  c.move(ratio, 0);
}

void draw() {

  // c.version();
  // c.querysteps();      // Uncomment for some extra info in the console
  // c.queryMotor();
  // c.queryPen();

  messageLoop(c.port); 

  String out = "";
  out += "pos[]: " + c.x() + "," + c.y() + " (steps)\n";
  out += "time: " + millis() + "ms\n";
  out += "idle: " + (c.idle()) + "\n";
  out += "headPos: " + (c.x()+ ", " + c.y()) + "\n";
  

  if (!c.enabled()) {
    out += "\nManually move the pen\nto the top left corner... \n\nPress F1 again when done.";
    background(220, 60, 60);
  } else {
    background(220);
  }
  
  

  fill(0, 140);
  text(out, 30, 30);
  
  
}

int steps = 800;             // 800 steps = 1cm

void keyPressed() {
  
  if (!c.idle()) return;
   
  if ( key == ' ') {         // Toggles the pen position
    if (c.pen() == Control.DOWN) {
      c.up();
    } else {
      c.down();
    }
  }else if(key == ENTER) { //move head to cursor location (a3 size)
    int time = 0;
    int newX = (mouseX*ratio)- c.x();
    int newY = (mouseY*ratio) - c.y();
    time += c.move(newX, newY); 
    print(time + "units");

  }
  
  
}
